@@ -3,12 +3,11 @@ import click
 
 from staircase.lib.click import async_cmd
 from staircase.env_storage import EnvironmentStorage 
-from staircase.command_providers import config_provider, env_storage_provider
+from staircase.command_providers import env_storage_provider
 from staircase.lib.fzf import prompt
 
 
 @click.command(name="remove")
-@config_provider()
 @env_storage_provider()
 @async_cmd
 async def command( env_storage: EnvironmentStorage, **_):
