@@ -30,12 +30,18 @@ from staircase.staircase import Staircase, StaircaseNotFoundBundle
 @postman_provider()
 @async_cmd
 async def command(
+    all: bool,
+    component: Union[str, bool],
+
     staircase: Staircase,
     postman: Postman,
-    component: Union[str, bool],
-    postman_client: PostmanClient,
-    all: bool
+    postman_client: PostmanClient
 ):
+    """
+    Import Staircase product to your Postman and use it with environment you imported.
+    Creates StaircaseAPI workspace.
+
+    """
 
     components = await staircase.get_all_product_components()
     if not components:
@@ -43,7 +49,7 @@ async def command(
     components_names = map(lambda e: e["name"], components)
 
     if not all and not component:
-        components_names = prompt(components_names, header="Select your component name", multi=True)
+        components_names = prompt(components_names, header="Select your component name | Select multiple via TAB", multi=True)
 
     workspaceid = postman.get_or_create_workspace()
 
@@ -59,7 +65,11 @@ async def command(
             )
             continue
 
+
+        click.echo(f"Downloading bundle...")
+        click.echo(bundle_url)
         r = requests.get(bundle_url, allow_redirects=True)
+        click.echo(f"Downloaded")
         with open(VAR_FOLDER / 'bundle.zip', 'wb') as f:
             f.write(r.content)
 
